DeviceGeolocationLinux class
Linux implementation of DeviceGeolocationPlatform backed by the
GeoClue2 D-Bus service (org.freedesktop.GeoClue2).
- Inheritance
-
- Object
- PlatformInterface
- DeviceGeolocationPlatform
- DeviceGeolocationLinux
Constructors
- DeviceGeolocationLinux({DBusClient? bus})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
settingsOpenedStream
→ Stream<
bool> -
Stream that emits
truewhen a system settings panel is opened by this plugin andfalsewhen the app returns to the foreground.no setteroverride
Methods
-
bearingBetween(
double startLatitude, double startLongitude, double endLatitude, double endLongitude) → double -
Initial bearing (forward azimuth) from start to end coordinates,
expressed in degrees.
inherited
-
checkPermission(
) → Future< DeviceLocationPermission> -
override
-
distanceBetween(
double startLatitude, double startLongitude, double endLatitude, double endLongitude, {GeospatialAlgorithm algorithm = GeospatialAlgorithm.vincenty}) → double -
Great-circle distance between two coordinates in meters.
inherited
-
getCurrentPosition(
{DeviceLocationSettings? deviceLocationSettings}) → Future< DevicePosition> -
override
-
getLocationAccuracy(
) → Future< DeviceLocationAccuracyStatus> -
override
-
getPermissionStream(
{Duration pollingInterval = const Duration(seconds: 1)}) → Stream< DeviceLocationPermission> -
override
-
getPositionStream(
{DeviceLocationSettings? deviceLocationSettings}) → Stream< DevicePosition> -
override
-
getServiceStatusStream(
) → Stream< DeviceLocationServiceStatus> -
override
-
isLocationServiceEnabled(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAppSettings(
{DeviceGeolocationSettingsCallback? callback}) → Future< bool> -
override
-
openLocationSettings(
{DeviceGeolocationSettingsCallback? callback}) → Future< bool> -
override
-
requestPermission(
{bool requestBackground = false}) → Future< DeviceLocationPermission> -
override
-
requestTemporaryFullAccuracy(
{required String purposeKey}) → Future< DeviceLocationAccuracyStatus> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void - Registers this implementation with DeviceGeolocationPlatform.instance.