DeviceGeolocationPlatform class abstract

Interface that all platform implementations of device_geolocation must implement.

Platform implementations should extend this class — not implement it — so that future additions do not break them.

Inheritance
  • Object
  • PlatformInterface
  • DeviceGeolocationPlatform
Implementers

Constructors

DeviceGeolocationPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bearingBetween(double startLatitude, double startLongitude, double endLatitude, double endLongitude) double
Initial bearing (forward azimuth) from start to end coordinates, expressed in degrees.
checkPermission() Future<LocationPermission>
distanceBetween(double startLatitude, double startLongitude, double endLatitude, double endLongitude) double
Great-circle distance between two coordinates in meters (Haversine).
getCurrentPosition({LocationSettings? locationSettings}) Future<Position>
getLastKnownPosition({bool forceLocationManager = false}) Future<Position?>
getLocationAccuracy() Future<LocationAccuracyStatus>
getPositionStream({LocationSettings? locationSettings}) Stream<Position>
getServiceStatusStream() Stream<ServiceStatus>
isLocationServiceEnabled() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSettings() Future<bool>
openLocationSettings() Future<bool>
requestPermission({bool requestBackground = false}) Future<LocationPermission>
requestTemporaryFullAccuracy({required String purposeKey}) Future<LocationAccuracyStatus>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DeviceGeolocationPlatform
Currently registered platform implementation.
getter/setter pair