settingsOpenedStream property

Stream<bool> get settingsOpenedStream

Stream that emits true when a system settings panel is opened by this plugin and false when the app returns to the foreground.

Implementation

Stream<bool> get settingsOpenedStream {
  throw UnimplementedError(
    'settingsOpenedStream has not been implemented.',
  );
}