lastForegroundNotificationConfig property

ForegroundNotificationConfig? get lastForegroundNotificationConfig

Convenience accessor for the ForegroundNotificationConfig carried by the most recent AndroidSettings passed to getPositionStream. Returns null when the last call did not use an AndroidSettings instance or the settings did not configure the foreground service.

Implementation

ForegroundNotificationConfig? get lastForegroundNotificationConfig {
  final settings = lastLocationSettings;
  return settings is AndroidSettings
      ? settings.foregroundNotificationConfig
      : null;
}