LocationPermission enum
Possible location permission states.
Values
- denied → const LocationPermission
-
Access is denied. The app may try requesting again.
- deniedForever → const LocationPermission
-
Access is permanently denied. The user must change it from settings.
- whileInUse → const LocationPermission
-
Access is granted only while the app is in use.
- always → const LocationPermission
-
Access is granted including when the app is in the background.
- unableToDetermine → const LocationPermission
-
Permission state cannot be determined (web fallback).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LocationPermission> - A constant List of the values in this enum, in order of their declaration.