DeviceGeolocationLinux class

Linux implementation of DeviceGeolocationPlatform backed by the GeoClue2 D-Bus service (org.freedesktop.GeoClue2).

Inheritance

Constructors

DeviceGeolocationLinux({DBusClient? bus})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bearingBetween(double startLatitude, double startLongitude, double endLatitude, double endLongitude) double
Initial bearing (forward azimuth) from start to end coordinates, expressed in degrees.
inherited
checkPermission() Future<LocationPermission>
override
distanceBetween(double startLatitude, double startLongitude, double endLatitude, double endLongitude) double
Great-circle distance between two coordinates in meters (Haversine).
inherited
getCurrentPosition({LocationSettings? locationSettings}) Future<Position>
override
getLastKnownPosition({bool forceLocationManager = false}) Future<Position?>
override
getLocationAccuracy() Future<LocationAccuracyStatus>
override
getPositionStream({LocationSettings? locationSettings}) Stream<Position>
override
getServiceStatusStream() Stream<ServiceStatus>
override
isLocationServiceEnabled() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSettings() Future<bool>
override
openLocationSettings() Future<bool>
override
requestPermission({bool requestBackground = false}) Future<LocationPermission>
override
requestTemporaryFullAccuracy({required String purposeKey}) Future<LocationAccuracyStatus>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void
Registers this implementation with DeviceGeolocationPlatform.instance.